@@ -13,9 +13,11 @@ from .queryset import QuerySet  # noqa
 from .wrappers import Wrapper  # noqa
 
 
+__version__ = '0.3.0'
+
 __all__ = (
     'ConfigMissingException',
-    'EmptyQuerySetException'
+    'EmptyQuerySetException',
     'ImproperlyConfigured',
     'ParsingException',
     'Query',
